pub struct LabelFormatOption {
pub include_packing_slip_with_label: Option<bool>,
pub label_format: Option<LabelFormat>,
}Expand description
LabelFormatOption : The label format details and whether to include a packing slip.
Fields
include_packing_slip_with_label: Option<bool>When true, include a packing slip with the label.
label_format: Option<LabelFormat>Implementations
sourceimpl LabelFormatOption
impl LabelFormatOption
sourcepub fn new() -> LabelFormatOption
pub fn new() -> LabelFormatOption
The label format details and whether to include a packing slip.